@@ -288,6 +288,47 @@ extern "C"
         return ppat->shift(0 - bbox[0], 0 - bbox[1]).digest();
     }
 
+    uint64_t GetPatternOctodigest(void* pat) {
+        auto ppat = reinterpret_cast<apg::pattern*>(pat);
+        if (ppat->empty()) { return 0; }
+
+        uint64_t digests[8];
+        uint8_t perms[8] = {27, 177, 78, 216, 39, 114, 141, 228};
+
+        for (int i = 0; i < 8; i++) {
+
+            auto lab = ppat->getlab();
+
+            apg::pattern tp(lab, lab->transform_recurse(ppat->gethnode(), perms[i]), ppat->getrule());
+
+            int64_t bbox[4];
+            tp.getrect(bbox);
+            digests[i] = tp.shift(0 - bbox[0], 0 - bbox[1]).digest();
+        }
+
+        for (int i = 7; i > 0; i--) {
+            for (int j = 0; j < i; j++) {
+                if (digests[j] > digests[j+1]) {
+                    uint64_t c = digests[j];
+                    digests[j] = digests[j+1];
+                    digests[j+1] = c;
+                }
+            }
+        }
+
+        uint64_t acc = digests[0];
+        uint64_t idx = 1;
+
+        for (int i = 1; i < 8; i++) {
+            if (digests[i] != digests[i-1]) {
+                idx += 2;
+                acc += digests[i] * idx;
+            }
+        }
+
+        return acc;
+    }
+
     void GetRuleOfPattern(void* pat, char* buffer) {
         auto ppat = reinterpret_cast<apg::pattern*>(pat);
         std::string s = ppat->getrule();
