@@ -56,11 +56,15 @@ class Pattern(object):
 
     def octodigest(self):
 
+        return self.lifelib('GetPatternOctodigest', self.ptr)
+
+        '''
         od = [self.digest()]
         for o in ["rot270", "rot180", "rot90", "flip_x", "flip_y", "swap_xy", "swap_xy_flip"]:
             od.append(self(o).digest())
         od = sorted(set(od))
         return sum([(2*i+1)*j for (i, j) in enumerate(od)]) & (2**64 - 1)
+        '''
 
     def advance(self, numgens, exponent=0):
 
@@ -520,7 +524,7 @@ class Pattern(object):
         header += '<div class="rle"><div style="display:none;"><code id="code2">\n'
         footer = '#C [[ WIDTH %d HEIGHT %d ]]\n' % (width, height)
         footer += '</code></div>\n<canvas width="%d" height="%d" style="margin-left:1px;"></canvas></div>\n' % (width+16, height+16)
-        footer += "<script type='text/javascript' src='https://gol.hatsya.co.uk/js/lv-plugin.js'></script>\n"
+        footer += "<script type='text/javascript' src='https://catagolue.hatsya.com/js/lv-plugin.js'></script>\n"
 
         if edit:
             # Generate a unique identifier for the IFrame, so that the Jupyter
